{% extends "base.html" %} {% block content %}
    <div class="post">
        <p>Si vous trouvez mon contenu intéressant, je vous invite à vous abonner à ma newsletter, ça ne vous coûte rien
            et permet de rester à jour, étant donné que je n'utilise aucun réseau social.</p>
        <link href="//cdn-images.mailchimp.com/embedcode/classic-10_7.css" rel="stylesheet" type="text/css">
        <div id="mc_embed_signup" style="width:500px">
            <form action="https://ouafi.us17.list-manage.com/subscribe/post?u=26c26b923489e66c9653cce5b&amp;id=f0388225cd"
                  method="post" id="mc-embedded-subscribe-form" name="mc-embedded-subscribe-form" class="validate"
                  target="_blank" novalidate>
                <div id="mc_embed_signup_scroll">
                    <h2>S'abonner à ma newsletter</h2>
                    <div class="indicates-required"><span class="asterisk">*</span> indique les champs requis</div>
                    <div class="mc-field-group">
                        <label for="mce-EMAIL">Addresse mail <span class="asterisk">*</span>
                        </label>
                        <input type="email" value="" name="EMAIL" class="required email" id="mce-EMAIL">
                    </div>
                    <div id="mce-responses" class="clear">
                        <div class="response" id="mce-error-response" style="display:none"></div>
                        <div class="response" id="mce-success-response" style="display:none"></div>
                    </div>
                    <!-- real people should not fill this in and expect good things - do not remove this or risk form bot signups-->
                    <div style="position: absolute; left: -5000px;" aria-hidden="true"><input type="text"
                                                                                              name="b_26c26b923489e66c9653cce5b_f0388225cd"
                                                                                              tabindex="-1" value="">
                    </div>
                    <div class="clear"><input type="submit" value="S'abonner" name="subscribe"
                                              id="mc-embedded-subscribe" class="button"></div>
                </div>
            </form>
        </div>
        <script type='text/javascript' src='//s3.amazonaws.com/downloads.mailchimp.com/js/mc-validate.js'></script>
        <script type='text/javascript'>
            (function ($) {
                window.fnames = new Array();
                window.ftypes = new Array();
                fnames[0] = 'EMAIL';
                ftypes[0] = 'email';
                fnames[1] = 'FNAME';
                ftypes[1] = 'text';
                fnames[2] = 'LNAME';
                ftypes[2] = 'text';
                fnames[3] = 'ADDRESS';
                ftypes[3] = 'address';
                fnames[4] = 'PHONE';
                ftypes[4] = 'phone';
                fnames[5] = 'BIRTHDAY';
                ftypes[5] = 'birthday';
            }(jQuery));
            var $mcj = jQuery.noConflict(true);
        </script>
        <!--End mc_embed_signup-->
    </div>
{% endblock %}
