{% extends "base.html" %}

{% block content %}
    <h1>Just between me and you.</h1>
    <h3>It looks like the page doesn't exist. Too bad, uh?<br/>You still can get back to the <a href="/">homepage</a>,
        though. Best of luck.</h3>
{% endblock %}
