.toc {
  background-color: #f6f6f6;
  border: 1px solid #eee;
  margin: 0 30px 5px 0;
  padding: 10px;
  h6 {
    font-size: 15px;
    font-weight: bold;
  }
  ul {
    padding: 0;
    margin: 0;
    li {
      margin: 0 0 !important;
      font-size: 17px;
      padding: 0;
      a {
		color: #111111;
		text-decoration: none;
		font-style: normal;
        border-bottom: 0;
      }
      &:last-child {
        padding-bottom: 0;
      }
      span {
        padding: 0 10px 0 0;
      }
      ul {
        margin: 0 !important;
        padding: 0 0 0 10px !important;
        li {
          font-size: 15px;
		  margin: -2px 0 0 0 !important;
		  list-style-type: circle !important;
        }
      }
    }
    li.intended {
      font-size: 12px !important;
      padding: 0 !important;
      line-height: 1.3 !important;
      padding-left: 30px !important;
    }
  }
}

@media screen and (max-width: 640px) {
  .toc {
    width: 100%;
    display: block;
    float: none;
  }
}

div#TOC {
  width: 20em;
  position: absolute;
  top: 0;
  right: 0;
  line-height: 110%;
}
